from django.urls import path
from django_maintenance import views

app_name = 'maintenance'

urlpatterns = [
    path('', views.index, name='maintenance_index'),
    path('<path:resource>', views.index),
]



from setuptools import setup

setup(
    long_description="django_maintenance is a Django app to conduct sheduled maintenance on your web application.Detailed documentation is in the 'docs' directory."
)